@@ -23,7 +23,7 @@ from aliyunsdkdds.endpoint import endpoint_data
 class CreateShardingDBInstanceRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Dds', '2015-12-01', 'CreateShardingDBInstance','dds')
+		RpcRequest.__init__(self, 'Dds', '2015-12-01', 'CreateShardingDBInstance','Dds')
 		self.set_method('POST')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
@@ -179,6 +179,12 @@ class CreateShardingDBInstanceRequest(RpcRequest):
 	def set_ZoneId(self,ZoneId):
 		self.add_query_param('ZoneId',ZoneId)
 
+	def get_ProtocolType(self):
+		return self.get_query_params().get('ProtocolType')
+
+	def set_ProtocolType(self,ProtocolType):
+		self.add_query_param('ProtocolType',ProtocolType)
+
 	def get_ChargeType(self):
 		return self.get_query_params().get('ChargeType')
 
